define(['resources/native-client-sdk-js/web-sdk'], function(WebSDK){
 'use strict';
 var eventHelper;
  
 var PageModule = function PageModule(context) {
  eventHelper = context.getEventHelper();
 };
  
 // Initialize bot
 PageModule.prototype.init = function() {
  console.log("Initializing bot...");
  var chatSettings = {
   URI: 'XXXXX',
   channelId: 'XXXXX',
   enableHeadless: true,
   enableSpeech: true,
   enableSpeechAutoSend: false
  };
 
  setTimeout(() => {
   window.Bots = new WebSDK(chatSettings);
   // Connect to bot
   window.Bots.connect().then(() => {
    console.log("Connection successful");
    eventHelper.fireCustomEvent('botStatus', true);
        
    // Setup message sent listener
    window.Bots.on('message:sent', function(message) {
     console.log("User sent a message", message);
     eventHelper.fireCustomEvent('messageSent', {message});
     window.scrollTo(0, document.body.scrollHeight);
    });
    // Setup message received listener
    window.Bots.on('message:received', function(message) {
     console.log("User received a message", message);
     eventHelper.fireCustomEvent('messageReceived', {message});
     window.scrollTo(0, document.body.scrollHeight);
    });
       
    // Setup network status change listener
    window.Bots.on('networkstatuschange', function(status) {
     var connected = false;
     switch (status) {
      case 0:
       status = 'Connecting';
       break;
      case 1:
       status = 'Open';
       connected = true;
       break;
      case 2:
       status = 'Closing';
       break;
      case 3:
       status = 'Closed';
       break;
     }
          
     eventHelper.fireCustomEvent('botStatus', connected);
     console.log(status);
    });

   }, (reason) => {
     console.log("Connection failed");
     console.log(reason);
   });
  }, 1000);
 };
  
 // Send message
 PageModule.prototype.sendMessage = function(message, type) {
  console.log("Sending message...");
  if (type && message) {
   window.Bots.sendMessage({
    "text" : message,
    "type": type
   });
  }
 };
 
 // get bot user id
 PageModule.prototype.getBotUserId = function() {
  console.log("get bot user id...");
  var userId =  window.Bots.getConversationHistory().userId;
  console.log("bot user id is:", userId)
  return userId
 };
 
 
 //this function decides if analytic call is needed or not. This is needed for the cases when intent name is passed in the botML intent.
 PageModule.prototype.checkMitCallNeed = function(message) {
    console.log("get checkMitCallNeed...");
    if(JSON.stringify(message).indexOf("#INTENT_NAME#:") > -1){
        console.log("skip intent name processing")
        var lastIntent = message.text.substring("#INTENT_NAME#:".length)
        return lastIntent
      }      
    
    return ''
 };
 
 //Process bot repsonse
 PageModule.prototype.mitProcessBotResponse = function(message) {
  console.log("get messagePayload::::::::::::########::::::::::::$$$::::::::", message);
   var lastIntent = ''
   const ansIntIdentifier = '<div id="intentName" style="display:none">'
    if(message != undefined && message.cards != undefined){
       //if it is carousel type no need to log all the cards. just first card description is enough
       return {
         "intent": lastIntent,
         "msg": message.cards[0].description
       }
     }else if(message != undefined && message.actions != undefined){
       return {
         "intent": lastIntent,
         "msg": message.text
       }
     }else if(message != undefined && message.type == 'attachment'){
       console.log("logging as commonResponseComponent intent")
       if(message.attachment.type == 'image'){
         console.log("logging as commonResponseComponent intent of type image")
         return {
         "intent": lastIntent,
         "msg": 'Image response'
         }
       }
     }else{
       console.log("logging as answer intent")
       let text = message.text
       if(message.text.indexOf(ansIntIdentifier) > -1){
           text = text.substring(text.indexOf('</div>') + '</div>'.length)
       }
       
       //get intent text
       let intText = message.text
        intText = intText.substring(intText.indexOf(ansIntIdentifier) + ansIntIdentifier.length )
        lastIntent = intText.substring(0, intText.indexOf("</div>"))
        return {
         "intent": lastIntent,
         "msg": text
         }
     }
 };
  
 // Start voice recording
 PageModule.prototype.startVoiceRecording = function() {
  console.log("Starting voice recording...");
  window.Bots.startVoiceRecording((data) => {
   var recognizedText = '';
   if (data && (data.event === 'finalResult' || data.event ===  'partialResult')) {
    if (data.nbest && data.nbest.length > 0) {
     recognizedText = data.nbest[0].utterance;
     document.getElementById("oj-input-text--1701864895-1").value = recognizedText;
    }
   }
      
   if (data && (data.event === 'finalResult')) {
    this.stopVoiceRecording();
   }
  }, (status, error) => {
   if (status === WebSocket.OPEN) {
    console.log("Connection established");
   } else if (status === WebSocket.CLOSED) {
    console.log("Connection closed");
   }
  });
 };
  
 // Stop voice recording
 PageModule.prototype.stopVoiceRecording = function() {
  console.log("Stopping voice recording...");
  window.Bots.stopVoiceRecording();
 };
 return PageModule;
});